##  Syncing Jira Data Manually
SAP LeanIX automatically synchronizes Jira data every 30 minutes to keep information current. For immediate updates, you can start a manual sync at any time.
To run a manual sync, do the following:
  1. Go to the **Agile Tracking** tab on the linked initiative fact sheet.
  2. Choose **Refresh data from Atlassian Jira**.![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio0c35b3eb127e4edbb478edfff3f6e107_LowRes.png)
Performing a Manual Sync
